@@ -1030,8 +1030,19 @@ fn pgp_verify_signature(key: Option<&PgpDigParams>,
             t!("digest prefix matches");
         }
 
-        return Err(Error::NoKey(
-            format!("Not provided (issuer: {})", issuer).into()));
+        if ! sig.pk_algo().is_supported() {
+            return Err(Error::NotTrusted(
+                format!("Signature relies on unknown or unsupported \
+                         cryptographic algorithm {}",
+                        sig.pk_algo())));
+        } else if legacy {
+            return Err(Error::NotTrusted(
+                "Signature relies on legacy crypto".into())
+                       .into());
+        } else {
+            return Err(Error::NoKey(
+                format!("Not provided (issuer: {})", issuer).into()));
+        }
     }
 }
 
@@ -1672,7 +1683,7 @@ fn _pgpParsePkts(armor: *const c_char,
 ffi!(
 /// Lints the first certificate in pkts.
 ///
-/// This function links the certificate according to the current
+/// This function lints the certificate according to the current
 /// [policy].  It warns about things like unusable subkeys, because they
 /// do not have a valid binding signature.  It will also generate a
 /// warning if there are no valid, signing-capable keys.
